@@ -4,18 +4,23 @@ package Slackware::Slackget::GPG;
 use warnings;
 use strict;
 use Slackware::Slackget::GPG::Signature ;
+use constant {
+	SIG_GOOD => 'GOOD',
+	SIG_BAD => 'BAD',
+	SIG_UNKNOW => 'UNKNOW',
+};
 
 =head1 NOM
 
-Slackware::Slackget::GPG - A simple class to verify files signatures with gpg
+Slackware::Slackget::GPG - A simple wrapper class to the gpg binary
 
 =head1 VERSION
 
-Version 0.1
+Version 0.4
 
 =cut
 
-our $VERSION = '0.1';
+our $VERSION = '0.4';
 
 =head1 SYNOPSIS
 
@@ -126,21 +131,132 @@ sub verify_file
 	return $sig;
 }
 
-=head2 import_signature
+=head2 import_key
 
-Import a signature file passed in parameter.
+Import a key file passed in parameter.
 
-	$gpg->import_signature('update/GPG-KEY') or die "unable to import official Slackware GnuPG key.\n";
+	$gpg->import_key('update/GPG-KEY') or die "unable to import official Slackware GnuPG key.\n";
 
-!! THIS METHOD IS NOT YET IMPLEMENTED !!
+Return a Slackware::Slackget::Signature object. 
+
+The returned object is set with the status (which represent in this case, the status of the import).
+
+On successfull import, it also set teh key_id and the emitter.
 
 =cut
 
-sub import_signature
+sub import_key
 {
-	1;
+	my ($self,$key) = @_ ;
+	my @out = `2>&1 LC_ALL=C $self->{DATA}->{gpg_binary} --import $key`;
+	my $sig = new Slackware::Slackget::GPG::Signature;
+	$sig->status('BAD');
+	foreach (@out){
+	# key 40102233: public key "Slackware Linux Project <security@slackware.com>" imported
+		if(/gpg: key ([^:]+): public key "([^"]+)" imported/){
+			$sig->status('GOOD');
+			$sig->key_id($1);
+			$sig->emitter($2);
+		}
+	}
+	
+	return $sig;
 }
 
+=head2 in_keyring
+
+Return the number of keys in the keyring that match the given string.
+
+    $gpg->in_keyring('Slackware Linux Project') or die "The GPG signature of the Slackware Linux project cannot be found in your keyring.\n";
+
+=cut
+
+sub in_keyring {
+	my ($self, $string) = @_ ;
+	my @r = ();
+	foreach my $key ( $self->list_keys ){
+		foreach (@{$key->{uid}}){
+			push @r, $key if(/$string/);
+		}
+	}
+	return scalar(@r);
+}
+
+=head2 list_keys
+
+Return the list of keys in the current user's keyring.
+
+=cut
+
+# Put the next line in the pod when the *info methods are coded.
+# To retrieve all information for a given key, use the key_info() method.
+
+sub list_keys {
+	my $self = shift;
+	my @list = ();
+	my @out = `2>&1 LC_ALL=C $self->{DATA}->{gpg_binary} --list-keys`;
+	#pub   1024D/61BD09B3 2005-07-02
+	foreach (@out){
+		chomp;
+		if(/^pub\s+[^\/]+\/([^\s]+)\s+.*$/){
+			push @list, {key => $1, uid => []};
+		}
+		elsif(/^uid\s+(.+)$/){
+			push @{ $list[$#list]->{uid} },$1;
+		}
+	}
+	return @list;
+}
+
+=head2 list_sigs
+
+Return the list of signatures in the current user's keyring.
+
+=cut
+
+# Put the next line in the pod when the *info methods are coded.
+# To retrieve all information for a given key, use the sig_info() method.
+
+sub list_sigs {
+	my $self = shift;
+	my @list = ();
+	my @out = `2>&1 LC_ALL=C $self->{DATA}->{gpg_binary} --list-sigs`;
+	foreach (@out){
+		chomp;
+		if(/^pub\s+[^\/]+\/([^\s]+)\s+.*$/){
+			push @list, $1;
+		}
+		elsif(/^uid\s+(.+)$/){
+			push @{ $list[$#list]->{uid} },$1;
+		}
+	}
+	return @list;
+}
+
+# =head2 sig_info
+# 
+# Retrieve info on one of the user's keyring signature.
+# 
+# This method takes a uid (or a significant part of it) as parameter. 
+# 
+# If the uid is not unique enough to select one signature, this method return undef.
+# 
+# =cut
+# # TODO: it sucks => list_* should return a list of key id and *_info return the rest of info !!
+# sub sig_info {
+# 	my ($self,$uid) = @_;
+# 	my @out = `2>&1 LC_ALL=C $self->{DATA}->{gpg_binary} --list-sigs`;
+# 	my $data = {};
+# 	foreach (@out){
+# 		chomp;
+# 		if(/^uid\s+$uid/){
+# 			$data->{uid} = $uid;
+# 		}elsif(defined($data->{uid}) && $data->{uid} eq $uid ){ # you are never to cautious with test...
+# 			if(//)
+# 		}
+# 	}
+# }
+
 
 
 =head1 ACCESSORS
