@@ -6,21 +6,34 @@ use strict;
 require Slackware::Slackget::Status ;
 use File::Copy ;
 
+use constant {
+	PKG_INSTALL_OK                  => 0x43001,
+	PKG_UPGRADE_OK                  => 0x43003,
+	PKG_REMOVE_OK                   => 0x43005,
+	PKG_INSTALL_FAIL                => 0x43002,
+	PKG_UPGRADE_FAIL                => 0x43004,
+	PKG_REMOVE_FAIL                 => 0x43006,
+	PKG_NOT_FOUND_INSTALL_FAIL      => 0x43007,
+	PKG_NOT_FOUND_UPGRADE_FAIL      => 0x43008,
+	PKG_NOT_FOUND_REMOVE_FAIL       => 0x43009,
+	PKG_UNKNOWN_FAIL                => 0x43010,
+};
+
 =head1 NAME
 
 Slackware::Slackget::PkgTools - A wrapper for the pkgtools action(installpkg, upgradepkg and removepkg)
 
 =head1 VERSION
 
-Version 1.0.0
+Version 1.0.21
 
 =cut
 
-our $VERSION = '1.0.0';
+our $VERSION = '1.0.21';
 
 =head1 SYNOPSIS
 
-This class is anoter wrapper for slack-get. It will encapsulate the pkgtools system call.
+This class is anoter wrapper for slack-get. It encapsulates the pkgtools system call.
 
     use Slackware::Slackget::PkgTools;
 
@@ -37,28 +50,34 @@ This class is anoter wrapper for slack-get. It will encapsulate the pkgtools sys
 
 sub new
 {
-	my ($class,$config) = @_ ;
+	my ($class,$config,%args) = @_ ;
 	return undef if(!defined($config) && ref($config) ne 'Slackware::Slackget::Config') ;
 	my $self={};
 	$self->{CONF} = $config ;
-	$self->{STATUS} = {
-		0 => "Package have been installed successfully.\n",
-		1 => "Package have been upgraded successfully.\n",
-		2 => "Package have been removed successfully.\n",
-		3 => "Can't install package : new package not found in the cache.\n",
-		4 => "Can't remove package : no such package installed.\n",
-		5 => "Can't upgrade package : new package not found in the cache.\n",
-		6 => "Can't install package : an error occured during $self->{CONF}->{common}->{pkgtools}->{'installpkg-binary'} system call\n",
-		7 => "Can't remove package : an error occured during $self->{CONF}->{common}->{pkgtools}->{'removepkg-binary'} system call\n",
-		8 => "Can't upgrade package : an error occured during $self->{CONF}->{common}->{pkgtools}->{'upgradepkg-binary'} system call\n",
-		9 => "Package scheduled for install on next reboot.\n",
-		10 => "An error occured in the Slackware::Slackget::PkgTool class (during installpkg, upgradepkg or removepkg) but the class is unable to understand the error.\n"
+	$self->{SUCCESS_STATUS} = {
+		Slackware::Slackget::PkgTools::PKG_INSTALL_OK	=> "Package have been installed successfully.",
+		Slackware::Slackget::PkgTools::PKG_UPGRADE_OK	=> "Package have been upgraded successfully.",
+		Slackware::Slackget::PkgTools::PKG_REMOVE_OK	=> "Package have been removed successfully.",
+	};
+	$self->{ERROR_STATUS}={
+		Slackware::Slackget::PkgTools::PKG_NOT_FOUND_INSTALL_FAIL	=> "Can't install package : new package not found in the cache.",
+		Slackware::Slackget::PkgTools::PKG_NOT_FOUND_REMOVE_FAIL	=> "Can't remove package : no such package installed.",
+		Slackware::Slackget::PkgTools::PKG_NOT_FOUND_UPGRADE_FAIL	=> "Can't upgrade package : new package not found in the cache.",
+		Slackware::Slackget::PkgTools::PKG_INSTALL_FAIL				=> "Can't install package : an error occured during $self->{CONF}->{common}->{pkgtools}->{'installpkg-binary'} system call",
+		Slackware::Slackget::PkgTools::PKG_REMOVE_FAIL				=> "Can't remove package : an error occured during $self->{CONF}->{common}->{pkgtools}->{'removepkg-binary'} system call",
+		Slackware::Slackget::PkgTools::PKG_UPGRADE_FAIL				=> "Can't upgrade package : an error occured during $self->{CONF}->{common}->{pkgtools}->{'upgradepkg-binary'} system call",
+		Slackware::Slackget::PkgTools::PKG_UNKNOWN_FAIL => "An error occured in the Slackware::Slackget::PkgTool class (during installpkg, upgradepkg or removepkg) but the class is unable to understand the error.",
 	};
 	$self->{DATA} = {
 		'info-output' => undef,
-		'connection-id' => 0
+		'connection-id' => 0,
+		'fake_mode' => 0,
 	};
+	$self->{DATA}->{'fake_mode'} = $args{'fake_mode'} if(defined($args{'fake_mode'}));
 	bless($self,$class);
+# 	
+# 	use Data::Dumper;
+# 	print Dumper($self);
 	
 	return $self;
 }
@@ -70,18 +89,11 @@ sub new
 Take a Slackware::Slackget::Config object as argument :
 
 	my $pkgtool = new Slackware::Slackget::PkgTool ($config);
-=cut
 
-sub _send_info
-{
-	my ($self,$action,$pkg) = @_;
-	my $client=0;
-	$client = $self->{DATA}->{'info-output'} if(defined($self->{DATA}->{'info-output'}) && $self->{DATA}->{'info-output'});
-	#print for debug purpose
-	print "[Slackware::Slackget::PkgTools::DEBUG] info:$self->{DATA}->{'connection-id'}:2:progress:file=$pkg;state=now$action\n";
-	
-	print $client->put("info:$self->{DATA}->{'connection-id'}:2:progress:file=$pkg;state=now$action\n") if($client && defined($self->{DATA}->{'connection-id'}) && $self->{DATA}->{'connection-id'});
-}
+** IMPORTANT NOTE ** : in the old time, when this module was poorly coded (by me) it was taking care of sending network messages.
+This is obviously not its role, so it do not do that anymore.
+
+=cut
 
 =head1 FUNCTIONS
 
@@ -113,41 +125,47 @@ sub install {
 	sub _install_package
 	{
 		my ($self,$pkg) = @_;
-		my $status = new Slackware::Slackget::Status (codes => $self->{STATUS});
-		#$self->{CONF}->{common}->{'update-directory'}/".$server->shortname."/cache/
-# 		print "[Slackware::Slackget::PkgTools::_install_package DEBUG] try to install package ",$pkg->get_id,"\n";
-		if($pkg->getValue('install_later'))
+		my $status = new Slackware::Slackget::Status (success_codes => $self->{SUCCESS_STATUS}, error_codes => $self->{ERROR_STATUS});
+		if( -e "$self->{CONF}->{common}->{'update-directory'}/package-cache/lock/".$pkg->get_id.".tgz")
 		{
-# 			print "[Slackware::Slackget::PkgTools::_install_package DEBUG] package ",$pkg->get_id," will be installed later.\n";
-			mkdir "/tmp/slack_get_boot_install" unless( -e "/tmp/slack_get_boot_install") ;
-		}
-		elsif( -e "$self->{CONF}->{common}->{'update-directory'}/package-cache/".$pkg->get_id.".tgz")
-		{
-			$self->_send_info('install',$pkg->get_id());
-# 			print "[Slackware::Slackget::PkgTools::_install_package DEBUG] log file : $self->{CONF}->{common}->{'log'}->{'log-file'}\n";
-			if(system("2>>$self->{CONF}->{common}->{'log'}->{'log-file'} $self->{CONF}->{common}->{pkgtools}->{'installpkg-binary'} $self->{CONF}->{common}->{'update-directory'}/package-cache/".$pkg->get_id.".tgz")==0)
+			print "\tTrying to install package: $self->{CONF}->{common}->{'update-directory'}/package-cache/lock/".$pkg->get_id.".tgz\n";
+			if(system("$self->{CONF}->{common}->{pkgtools}->{'installpkg-binary'} $self->{CONF}->{common}->{'update-directory'}/package-cache/lock/".$pkg->get_id.".tgz")==0)
 			{
-# 				print "[Slackware::Slackget::PkgTools::_install_package DEBUG] package ",$pkg->get_id," have been correctly installed\n";
-				$status->current(0);
+				print "Slackware::Slackget::install: package successfully installed.\n";
+				$status->current(PKG_INSTALL_OK);
 				return $status ;
 			}
 			else
 			{
-# 				print "[Slackware::Slackget::PkgTools::_install_package DEBUG] package ",$pkg->get_id," have NOT been correctly installed\n";
-				$status->current(6);
+				print "Slackware::Slackget::install: an error occured while installing package.\n";
+				$status->current(PKG_INSTALL_FAIL);
 				return $status ;
 			}
-			
 		}
 		else
 		{
-# 			print "[Slackware::Slackget::PkgTools::_install_package DEBUG] package ",$pkg->get_id," can't be installed.\n";
-			$status->current(3);
+			$status->current(PKG_NOT_FOUND_INSTALL_FAIL);
+			print "\tUnable to install package: $self->{CONF}->{common}->{'update-directory'}/package-cache/lock/".$pkg->get_id.".tgz\n";
 			return $status ;
 		}
 	}
 	my ($self,$object) = @_;
-	if(ref($object) eq 'Slackware::Slackget::PackageList')
+	if( -e $object ){
+		print "Slackware::Slackget::install: installing package from a file name (not a Slackware::Slackget::Package)\n";
+		my $status = new Slackware::Slackget::Status (success_codes => $self->{SUCCESS_STATUS}, error_codes => $self->{ERROR_STATUS});
+		if(system("$self->{CONF}->{common}->{pkgtools}->{'installpkg-binary'} $object")==0)
+		{
+			$status->current(PKG_INSTALL_OK);
+			return $status ;
+		}
+		else
+		{
+			$status->current(PKG_INSTALL_FAIL);
+			return $status ;
+		}
+		return $status ;
+	}
+	elsif(ref($object) eq 'Slackware::Slackget::PackageList')
 	{
 # 		print "[install] Do the job for a Slackware::Slackget::PackageList\n";
 		foreach my $pack ( @{ $object->get_all() })
@@ -183,31 +201,45 @@ sub upgrade {
 	sub _upgrade_package
 	{
 		my ($self,$pkg) = @_;
-		my $status = new Slackware::Slackget::Status (codes => $self->{STATUS});
+		my $status = new Slackware::Slackget::Status (success_codes => $self->{SUCCESS_STATUS}, error_codes => $self->{ERROR_STATUS});
 		#$self->{CONF}->{common}->{'update-directory'}/".$server->shortname."/cache/
-		if( -e "$self->{CONF}->{common}->{'update-directory'}/package-cache/".$pkg->get_id.".tgz")
+		if( -e "$self->{CONF}->{common}->{'update-directory'}/package-cache/lock/".$pkg->get_id.".tgz")
 		{
-			$self->_send_info('upgrade',$pkg->get_id());
-# 			print "\tTrying to upgrade package: $self->{CONF}->{common}->{'update-directory'}/package-cache/".$pkg->get_id.".tgz\n";
-			if(system("2>>$self->{CONF}->{common}->{'log'}->{'log-file'} $self->{CONF}->{common}->{pkgtools}->{'upgradepkg-binary'} $self->{CONF}->{common}->{'update-directory'}/package-cache/".$pkg->get_id.".tgz")==0)
+			print "\tTrying to upgrade package: $self->{CONF}->{common}->{'update-directory'}/package-cache/lock/".$pkg->get_id.".tgz\n";
+			if(system("$self->{CONF}->{common}->{pkgtools}->{'upgradepkg-binary'} $self->{CONF}->{common}->{'update-directory'}/package-cache/lock/".$pkg->get_id.".tgz")==0)
 			{
-				$status->current(1);
+				$status->current(PKG_UPGRADE_OK);
 				return $status ;
 			}
 			else
 			{
-				$status->current(8);
+				$status->current(PKG_UPGRADE_FAIL);
 				return $status ;
 			}
 		}
 		else
 		{
-			$status->current(5);
+			$status->current(PKG_NOT_FOUND_UPGRADE_FAIL);
+			print "\tUnable to upgrade package: $self->{CONF}->{common}->{'update-directory'}/package-cache/lock/".$pkg->get_id.".tgz\n";
 			return $status ;
 		}
 	}
 	my ($self,$object) = @_;
-	if(ref($object) eq 'Slackware::Slackget::PackageList')
+	if( -e $object ){
+		my $status = new Slackware::Slackget::Status (success_codes => $self->{SUCCESS_STATUS}, error_codes => $self->{ERROR_STATUS});
+		if(system("$self->{CONF}->{common}->{pkgtools}->{'upgradepkg-binary'} $object")==0)
+		{
+			$status->current(PKG_UPGRADE_OK);
+			return $status ;
+		}
+		else
+		{
+			$status->current(PKG_UPGRADE_FAIL);
+			return $status ;
+		}
+		return $status ;
+	}
+	elsif(ref($object) eq 'Slackware::Slackget::PackageList')
 	{
 # 		print "Do the job for a Slackware::Slackget::PackageList\n";
 		foreach my $pack ( @{ $object->get_all() })
@@ -217,11 +249,12 @@ sub upgrade {
 	}
 	elsif(ref($object) eq 'Slackware::Slackget::Package')
 	{
-# 		print "Do the job for a Slackware::Slackget::Package\n";
+		print "Slackware::Slackget::upgrade: Do the job for a Slackware::Slackget::Package\n";
 		$object->status($self->_upgrade_package($object));
 	}
 	else
 	{
+		print "Slackware::Slackget::upgrade: returning an undefined value for because \$object do not match required types.\n";
 		return undef;
 	}
 }
@@ -231,7 +264,7 @@ sub upgrade {
 Take a single Slackware::Slackget::Package object or a single Slackware::Slackget::PackageList as argument and call installpkg on all this packages.
 Return 1 or undef if an error occured. But methods from the Slackware::Slackget::PkgTools class don't return on the first error, it will try to install all packages. Additionnally, for each package, set a status. 
 
-	$pkgtool->install($package_list);
+	$pkgtool->remove($package_list);
 
 =cut
 
@@ -240,26 +273,29 @@ sub remove {
 	sub _remove_package
 	{
 		my ($self,$pkg) = @_;
-		my $status = new Slackware::Slackget::Status (codes => $self->{STATUS});
+		my $status = new Slackware::Slackget::Status (success_codes => $self->{SUCCESS_STATUS}, error_codes => $self->{ERROR_STATUS});
 		#$self->{CONF}->{common}->{'update-directory'}/".$server->shortname."/cache/
 		if( -e "$self->{CONF}->{common}->{'packages-history-dir'}/".$pkg->get_id)
 		{
-			$self->_send_info('remove',$pkg->get_id());
 # 			print "\tTrying to remove package: ".$pkg->get_id."\n";
-			if(system("2>>$self->{CONF}->{common}->{'log'}->{'log-file'} $self->{CONF}->{common}->{pkgtools}->{'removepkg-binary'} ".$pkg->get_id)==0)
+			# TODO: the error output is not logged anymore in the PkgTools calls. It must be fixed.
+			if(system("$self->{CONF}->{common}->{pkgtools}->{'removepkg-binary'} ".$pkg->get_id)==0)
 			{
-				$status->current(2);
+				print "[Slackware::Slackget::PkgTools] (removepkg) setting (success) status ",PKG_REMOVE_OK,"\n";
+				$status->current(PKG_REMOVE_OK);
 				return $status ;
 			}
 			else
 			{
-				$status->current(7);
+				print "[Slackware::Slackget::PkgTools] (removepkg) setting (failed) status ",PKG_REMOVE_FAIL,"\n";
+				$status->current(PKG_REMOVE_FAIL);
 				return $status ;
 			}
 		}
 		else
 		{
-			$status->current(4);
+			print "[Slackware::Slackget::PkgTools] (removepkg) setting (fail) status ",PKG_NOT_FOUND_REMOVE_FAIL,"\n";
+			$status->current(PKG_NOT_FOUND_REMOVE_FAIL);
 			return $status ;
 		}
 	}
@@ -283,34 +319,6 @@ sub remove {
 	}
 }
 
-=head2 info_output
-
-Accessor to set/get the output medium to send informations about current operation. You must set a valid handle (STD*, filehandle, socket, etc.) or undef.
-
-You can get an undefined value if the handle is not set.
-
-Setting the output media activate the output system.
-
-=cut
-
-sub info_output
-{
-	return $_[1] ? $_[0]->{DATA}->{'info-output'}=$_[1] : $_[0]->{DATA}->{'info-output'};
-}
-
-=head2 connection_id
-
-Accessor to set/get the connection id of a connection to or from a slack-get daemon. This is here if the output handle is that kind of connection. Anyway this value must be true so set it to 1 if you want an output.
-
-=cut
-
-sub connection_id
-{
-	return $_[1] ? $_[0]->{DATA}->{'connection-id'}=$_[1] : $_[0]->{DATA}->{'connection-id'};
-}
-
-
-
 =head1 AUTHOR
 
 DUPUIS Arnaud, C<< <a.dupuis@infinityperl.org> >>
@@ -336,7 +344,7 @@ You can also look for information at:
 
 =item * Infinity Perl website
 
-L<http://www.infinityperl.org>
+L<http://www.infinityperl.org/category/slack-get>
 
 =item * slack-get specific website
 
