@@ -155,9 +155,11 @@ TIPS: you can restrict the search domain by providing fields with restrictions,
 sub search_package_multi_fields {
 	my ($self,$string,@fields)=@_;
 	my @result;
+# 	print STDERR "[Slackware::Slackget::Search->search_package_multi_fields()] (debug) begin the search.\n";
 	foreach (@{$self->{PKGLIST}->get_all()}){
 		foreach my $field (@fields)
 		{
+# 			print STDERR "[Slackware::Slackget::Search->search_package_multi_fields()] (debug) compare \"$string\" with package ".$_->get_id()." field $field (".$_->getValue($field).")\n";
 			if($field=~ /^([^=]+)=(.+)/)
 			{
 				if(defined($_->getValue($1)) && $_->getValue($1) ne $2)
@@ -200,12 +202,14 @@ sub multi_search
 		my $cpt = 0 ;
 		foreach my $field (@{$fields})
 		{
+# 			print STDERR "[Slackware::Slackget::Search->multi_search()] (debug) looking for field: $field\n";
 			my $field_value;
 			if($field=~ /^([^=]+)=(.+)/)
 			{
+# 				print STDERR "[Slackware::Slackget::Search->multi_search()] (debug) got a A=B type field (A=$1 and B=$2)\n";
 				if(defined($_->getValue($1)) && $_->getValue($1) ne $2)
 				{
-					$is_result = undef;
+					$is_result = 0;
 					last ;
 				}
 				elsif(defined($_->getValue($1)) && $_->getValue($1) eq $2)
@@ -238,7 +242,7 @@ sub multi_search
 		{
 			print STDERR "[slack-get] (search engine debug) package ",$_->get_id," got a score of $cpt and a 'is_result' of $is_result\n" if($is_result && $cpt);
 			$_->setValue('score',$cpt);
-			$_->setValue('slackget10-search-version',$VERSION);
+			$_->setValue('slackware-slackget-search-version',$VERSION);
 			push @result, $_ ;
 		}
 	}
@@ -270,7 +274,7 @@ You can also look for information at:
 
 =item * Infinity Perl website
 
-L<http://www.infinityperl.org>
+L<http://www.infinityperl.org/category/slack-get>
 
 =item * slack-get specific website
 
